/*
 * Copyright (C) 2003-2004 John David Ratliff
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package nan.controller;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JMenuItem;
import javax.swing.JPopupMenu;

import nan.tools.EventLogger;

import nan.view.View;

/**
 * A Popup Menu used to display message sources.
 *
 * @author John David Ratliff
 * @version 1.1, 12/29/03
 */
public class MessagePopupMenu extends JPopupMenu implements ActionListener {
    private View view;
    private static final String SOURCE_ACTION = "_source";

    /**
     * Creates a new MessagePopupMenu object.
     *
     * @param view The View.
     */
    public MessagePopupMenu(View view) {
        super();

        this.view = view;

        JMenuItem source = new JMenuItem("View Selected Message Source");
        source.setActionCommand(SOURCE_ACTION);
        source.addActionListener(this);

        add(source);
    }

    /**
     * Called when source is selected.
     */
    private void sourceAction() {
        this.view.showCurrentMessageSource();
    }

    /**
     * The registered callback for events on this menu.
     *
     * @param event The event that triggered this callback.
     */
    public void actionPerformed(ActionEvent event) {
        String action = event.getActionCommand();

        if (action.equals(SOURCE_ACTION)) {
            sourceAction();
        } else {
            EventLogger.getInstance().logError("Unknown action command " +
                                               action +
                                               " in MessagePopupMenu.actionPerformed()...");
        }
    }

    /**
     * Returns a String representation of this Menu.
     *
     * @return A String representation.
     */
    public String toString() {
        return "MessagePopupMenu[view=" + this.view + "]";
    }
}
