/*
 * Copyright (C) 2003-2004 John David Ratliff
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package nan.nntp;

/**
 * An interface for examining NNTP responses.
 *
 * @author John David Ratliff
 * @version 1.1, 12/24/03
 */
public interface NNTPResponse {
    /**
     * Gets the status code of the NNTP response.
     *
     * @return The status code.
     */
    public int getStatusCode();

    /**
     * Gets the status message.
     *
     * @return The status message.
     */
    public String getStatusMessage();

    /**
     * Asks if this response has a text component.
     *
     * @return true if this response has text; false otherwise.
     */
    public boolean hasText();

    /**
     * Gets the text of this response.
     *
     * @return The text.
     */
    public String getText();

    /**
     * Gets the number of lines in the text component.
     *
     * @return The line count.
     */
    public int getLineCount();
}
