/*
 * Copyright (C) 2003-2004 John David Ratliff
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package nan.tools;

import java.io.File;
import java.io.FileOutputStream;

import nan.model.Attachment;

/**
 * A Background task to handle attachment saving to disk.
 *
 * @author John David Ratliff
 * @version 1.1, 1/6/04
 */
public class BackgroundAttachmentSaver extends AbstractBackgroundTask {
    private Attachment attachment;
    private File file;

    /**
     * Creates a new BackgroundAttachmentSaver object.
     *
     * @param attachment The Attachment.
     * @param file The File to save it to.
     */
    public BackgroundAttachmentSaver(Attachment attachment, File file) {
        this.attachment = attachment;
        this.file = file;
    }

    /**
     * Serializes the attachment to file.
     */
    public void run() {
        try {
            byte[] data = attachment.decode();

            FileOutputStream output = new FileOutputStream(file);
            output.write(data);
            output.close();
        } catch (Exception e) {
            EventLogger.getInstance().logError(e.toString() +
                                               " in BackgroundAttachmentSaver.run()...");
        }

        finished = true;
    }

    /**
     * Returns a String representation of this object.
     *
     * @return A String representation.
     */
    public String toString() {
        return "BackgroundAttachmentSaver[attachment=" + attachment +
               ", file=" + file + "]";
    }
}
