/*
 * Copyright (C) 2003-2004 John David Ratliff
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package nan.tools;

import java.io.File;

import nan.model.XMLSerializable;

import org.dom4j.Document;

/**
 * Performs a serialization task in a background thread.
 *
 * @author John David Ratliff
 * @version 1.5, 1/1/04
 */
public class BackgroundWriter extends AbstractBackgroundTask {
    private XMLSerializable data;
    private File file;

    /**
     * Creates a new BackgroundWriter object.
     *
     * @param data The XML expressible data to be serialized.
     * @param file The file to serialize it to.
     */
    public BackgroundWriter(XMLSerializable data, File file) {
        super();

        this.data = data;
        this.file = file;
    }

    /**
     * Starts the thread and performs the serialization task.
     */
    public void run() {
        try {
            Document document = data.toXML();
            XMLSerializer.write(document, file);
        } catch (Exception e) {
            // don't let an exception crash the program
            EventLogger.getInstance().logError(e.toString() +
                                               " during BackgroundWriter.run()...");
        }

        finished = true;
    }

    /**
     * Returns a String representation of this BackgroundWriter.
     *
     * @return A String representation.
     */
    public String toString() {
        return "BackgroundWriter[data=" + data + ", file=" + file + "]";
    }
}
