/*
 * Copyright (C) 2003-2004 John David Ratliff
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package nan.view;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Toolkit;

import javax.swing.JDialog;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.WindowConstants;

/**
 * A dialog used to display the source information on Messages.
 *
 * @author John David Ratliff
 * @version 1.3, 12/29/03
 */
public class SourceDialog extends JDialog {
    private JScrollPane scroller;
    private JTextArea source;

    /**
     * Creates a new SourceDialog object.
     *
     * @param parent The parent of this dialog.
     */
    public SourceDialog(Frame parent) {
        super(parent, true);

        initComponents();
    }

    /**
     * Initializes the dialog components.
     */
    private void initComponents() {
        setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);

        scroller = new JScrollPane();
        source = new JTextArea();

        scroller.setViewportView(source);
        getContentPane().add(scroller, BorderLayout.CENTER);

        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        setBounds((screenSize.width - 400) / 2,
                  (screenSize.height - 400) / 2, 400, 400);
    }

    /**
     * Displays this dialog with the source text.
     *
     * @param title The Title for the dialog.
     * @param source The source text.
     */
    public void display(String title, String source) {
        setTitle(title);
        this.source.setText(source);
        this.source.setCaretPosition(0);
        this.setVisible(true);
    }

    /**
     * Returns a String representation of this dialog.
     *
     * @return A String representation.
     */
    public String toString() {
        return "SourceDialog[scroller=" + this.scroller + ", source=" +
               this.source + "]";
    }
}
